import { queryAuthWarehouse, warehouseAllList } from '@/api/warehouse'
const warehouse = {
  template: `
      <a-select
        :placeholder="placeholder"
        :id="id"
        :allowClear="allowClear"
        :value="defaultVal"
        :showSearch="true"
        :disabled="disabled"
        :mode="modeType"
        @change="handleChange"
        :filter-option="filterOption">
        <a-select-option v-for="item in warehouseData" :key="item.warehouseSn" :value="item.warehouseSn">{{ item.name }}</a-select-option>
      </a-select>
    `,
  props: {
    value: {
      type: [String, Array],
      defatut: ''
    },
    isPermission: {// false无权限 true有权限
      type: Boolean,
      default: false
    },
    allowClear: {
      type: Boolean,
      default: true
    },
    id: {
      type: String,
      default: ''
    },
    placeholder: {
      type: String,
      default: '请选择仓库'
    },
    disabled: {
      type: Boolean,
      default: false
    },
    modeType: {
      type: String,
      default: 'default'
    },
    isDefault: { // 是否有默认值
      type: Boolean,
      default: undefined
    }
  },
  data () {
    return {
      defaultVal: this.value,
      warehouseData: [],
      pageNo: 1,
      pageSize: 1000
    }
  },
  mounted () {
    if (this.isPermission) {
      this.$store.state.app.defWarehouse = null
      this.$store.state.app.isWarehouse = false
    }
    this.getWarehouse()
  },
  watch: {
    value (newValue, oldValue) {
      this.defaultVal = newValue
    }
  },
  methods: {
    filterOption (input, option) {
      return (
        option.componentOptions.children[0].text.toLowerCase().indexOf(input.toLowerCase()) >= 0
      )
    },
    handleChange (value) {
      this.defaultVal = value
      this.$emit('input', value)
      this.$emit('change', value)
    },
    //  获取仓库列表
    getWarehouse () {
      const ajaxName = this.isPermission ? queryAuthWarehouse : warehouseAllList
      ajaxName({}).then(res => {
        if (res.status == 200) {
          // 有权限控制的
          if (this.isPermission) {
            this.$store.state.app.isWarehouse = res.data && res.data.length > 1
            this.$store.state.app.defWarehouse = res.data && res.data[0]
          }
          this.warehouseData = res.data || []
          let defaultWarehouseVal = {}
          if (this.isDefault) {
            defaultWarehouseVal = res.data.find(con => {
              return con.defaultFlag == 1 ? con.warehouseSn : ''
            })
            this.defaultVal = defaultWarehouseVal.warehouseSn
            this.$emit('load', defaultWarehouseVal.warehouseSn)
          } else {
            this.$emit('load')
          }
        } else {
          if (this.isPermission) {
            this.$store.state.app.isWarehouse = false
            this.$store.state.app.defWarehouse = null
          }
          this.warehouseData = []
        }
      })
    },
    clearData () {
      this.handleChange([])
    }
  }
}

export default warehouse
